==> django-appointment-1.1.0.tar.gz: django-appointment-1.1.0/docs/views.md <==
- [Django Appointment System](#django-appointment-system)
  * [Views](#views)
    + [get_available_slots_ajax](#get-available-slots-ajax)
    + [get_next_available_date_ajax](#get-next-available-date-ajax)
    + [appointment_request](#appointment-request)
    + [appointment_request_submit](#appointment-request-submit)
    + [redirect_to_payment_or_thank_you_page](#redirect-to-payment-or-thank-you-page)
    + [create_appointment](#create-appointment)
    + [get_client_data_from_post](#get-client-data-from-post)
    + [get_appointment_data_from_post_request](#get-appointment-data-from-post-request)
    + [create_user_and_send_email](#create-user-and-send-email)
    + [appointment_client_information](#appointment-client-information)
    + [verify_user_and_login](#verify-user-and-login)
    + [enter_verification_code](#enter-verification-code)
    + [default_thank_you](#default-thank-you)


# Django Appointment System

## Views

### get available slots ajax
This view function handles AJAX requests to get available slots for a selected date.

#### Args:
- `request` (django.http.HttpRequest): The request instance.

#### Returns:
- `django.http.JsonResponse`: A JSON response containing available slots, selected date, an error flag, and an optional error message.

### get next available date ajax
This view function handles AJAX requests to get the next available date for a service.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `service_id` (int): The ID of the service.

#### Returns:
- `django.http.JsonResponse`: A JSON response containing the next available date.

### appointment request
This view function handles requests to book an appointment for a service.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `service_id` (int): The ID of the service.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.

### appointment request submit
This view function handles the submission of the appointment request form.

#### Args:
- `request` (django.http.HttpRequest): The request instance.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.

### redirect to payment or thank you page
This function redirects to the payment page or the thank you page based on the configuration.

#### Args:
- `appointment` (appointment.models.Appointment): The Appointment instance.

#### Returns:
- `django.http.HttpResponseRedirect`: The redirect response.

### create appointment
This function creates a new appointment and redirects to the payment page or the thank you page.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `appointment_request_obj` (appointment.models.AppointmentRequest): The AppointmentRequest instance.
- `client_data` (dict): The client data.
- `appointment_data` (dict): The appointment data.

#### Returns:
- `django.http.HttpResponseRedirect`: The redirect response.

### get client data from post
This function retrieves client data from the POST request.

#### Args:
- `request` (django.http.HttpRequest): The request instance.

#### Returns:
- `dict`: The client data.

### get appointment data from post request
This function retrieves appointment data from the POST request.

#### Args:
- `request` (django.http.HttpRequest): The request instance.

#### Returns:
- `dict`: The appointment data.

### create user and send email
This function creates a new user, sends a thank you email, and notifies the admin.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `ar` (appointment.models.AppointmentRequest): The AppointmentRequest instance.
- `client_data` (dict): The client data.
- `appointment_data` (dict): The appointment data.

#### Returns:
- `django.contrib.auth.models.User`: The newly created user.

### appointment client information
This view function handles client information submission for an appointment.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `appointment_request_id` (int): The ID of the appointment request.
- `id_request` (str): The unique ID of the appointment request.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.

### verify user and login
This function verifies the user's email and logs the user in.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `user` (appointment.models.User): The User instance.
- `code` (str): The verification code.

#### Returns:
- `bool`: True if the user is verified and logged in, False otherwise.

### enter verification code
This view function handles the submission of the email verification code.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `appointment_request_id` (int): The ID of the appointment request.
- `id_request` (str): The unique ID of the appointment request.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.

### default thank you
This view function handles the default thank you page.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `appointment_id` (int): The ID of the appointment.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.

==> django-appointment-1.1.2.tar.gz: django-appointment-1.1.2/docs/views.md <==
- [Django Appointment System](#django-appointment-system)
  * [Views](#views)
    + [get_available_slots_ajax](#get-available-slots-ajax)
    + [get_next_available_date_ajax](#get-next-available-date-ajax)
    + [appointment_request](#appointment-request)
    + [appointment_request_submit](#appointment-request-submit)
    + [redirect_to_payment_or_thank_you_page](#redirect-to-payment-or-thank-you-page)
    + [create_appointment](#create-appointment)
    + [get_client_data_from_post](#get-client-data-from-post)
    + [get_appointment_data_from_post_request](#get-appointment-data-from-post-request)
    + [create_user_and_notify_admin](#create-user-and-send-email)
    + [appointment_client_information](#appointment-client-information)
    + [verify_user_and_login](#verify-user-and-login)
    + [enter_verification_code](#enter-verification-code)
    + [default_thank_you](#default-thank-you)


# Django Appointment System

## Views

### get available slots ajax
This view function handles AJAX requests to get available slots for a selected date.

#### Args:
- `request` (django.http.HttpRequest): The request instance.

#### Returns:
- `django.http.JsonResponse`: A JSON response containing available slots, selected date, an error flag, and an optional error message.

### get next available date ajax
This view function handles AJAX requests to get the next available date for a service.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `service_id` (int): The ID of the service.

#### Returns:
- `django.http.JsonResponse`: A JSON response containing the next available date.

### appointment request
This view function handles requests to book an appointment for a service.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `service_id` (int): The ID of the service.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.

### appointment request submit
This view function handles the submission of the appointment request form.

#### Args:
- `request` (django.http.HttpRequest): The request instance.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.

### redirect to payment or thank you page
This function redirects to the payment page or the thank you page based on the configuration.

#### Args:
- `appointment` (appointment.models.Appointment): The Appointment instance.

#### Returns:
- `django.http.HttpResponseRedirect`: The redirect response.

### create appointment
This function creates a new appointment and redirects to the payment page or the thank you page.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `appointment_request_obj` (appointment.models.AppointmentRequest): The AppointmentRequest instance.
- `client_data` (dict): The client data.
- `appointment_data` (dict): The appointment data.

#### Returns:
- `django.http.HttpResponseRedirect`: The redirect response.

### get client data from post
This function retrieves client data from the POST request.

#### Args:
- `request` (django.http.HttpRequest): The request instance.

#### Returns:
- `dict`: The client data.

### get appointment data from post request
This function retrieves appointment data from the POST request.

#### Args:
- `request` (django.http.HttpRequest): The request instance.

#### Returns:
- `dict`: The appointment data.

### create user and send email
This function creates a new user, sends a thank you email, and notifies the admin.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `ar` (appointment.models.AppointmentRequest): The AppointmentRequest instance.
- `client_data` (dict): The client data.
- `appointment_data` (dict): The appointment data.

#### Returns:
- `django.contrib.auth.models.User`: The newly created user.

### appointment client information
This view function handles client information submission for an appointment.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `appointment_request_id` (int): The ID of the appointment request.
- `id_request` (str): The unique ID of the appointment request.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.

### verify user and login
This function verifies the user's email and logs the user in.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `user` (appointment.models.User): The User instance.
- `code` (str): The verification code.

#### Returns:
- `bool`: True if the user is verified and logged in, False otherwise.

### enter verification code
This view function handles the submission of the email verification code.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `appointment_request_id` (int): The ID of the appointment request.
- `id_request` (str): The unique ID of the appointment request.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.

### default thank you
This view function handles the default thank you page.

#### Args:
- `request` (django.http.HttpRequest): The request instance.
- `appointment_id` (int): The ID of the appointment.

#### Returns:
- `django.http.HttpResponse`: The rendered HTML page.
